@@ -1,6 +1,6 @@
 package MARC::Moose;
 BEGIN {
-  $MARC::Moose::VERSION = '0.010';
+  $MARC::Moose::VERSION = '0.011';
 }
 # ABSTRACT: Moose based MARC records set of tools
 
@@ -24,7 +24,7 @@ MARC::Moose - Moose based MARC records set of tools
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
@@ -41,6 +41,17 @@ version 0.010
  );
  my $formater = MARC::Moose::Formater::Text->new();
  while ( my $record = $reader->read() ) {
+     # Remove some fields
+     $record->fields([
+         grep { not $_->tag ~~ [qw(001 009 039 917 930 955)] } @{$record->fields}
+     ]);
+     # Clean some subfields
+     for my $field ( @{$record->fields} ) {
+        next unless $field->tag ~~ [qw(410 461 600 606 607 608)];
+        $field->subf([
+          grep { not $_->[0] =~ /0|2|3|9/ } @{$field->subf}
+        ]);
+     }
      print $formater->format( $record );
  }
 
